==> ejc-zdsmaterialb-api-3.0.0-20241114.034118-44-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MatSupplierManagerVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 采购计划控制方式
 * 
 * @author generator
 * 
 */
public class MatSupplierManagerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String memo; // 备注
    private Long categoryId; // 材料分类id
    private String categoryName; // 材料分类名称
    private String categoryInnerCode; // 材料分类内码
    private Long managerId; //审核人Id
    private String managerName; //审核人名称
    private String managerCode; //审核人编码
    private String managerPostName; //审核人岗位
    private Long managerPostId; //审核人岗位Id

    public Long getManagerPostId() {
        return managerPostId;
    }

    public void setManagerPostId(Long managerPostId) {
        this.managerPostId = managerPostId;
    }

    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }

    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }

    public String getManagerCode() {
        return managerCode;
    }

    public void setManagerCode(String managerCode) {
        this.managerCode = managerCode;
    }

    public String getManagerPostName() {
        return managerPostName;
    }

    public void setManagerPostName(String managerPostName) {
        this.managerPostName = managerPostName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getCategoryInnerCode() {
        return categoryInnerCode;
    }

    public void setCategoryInnerCode(String categoryInnerCode) {
        this.categoryInnerCode = categoryInnerCode;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251205.101044-99-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MatSupplierManagerVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 采购计划控制方式
 * 
 * @author generator
 * 
 */
public class MatSupplierManagerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String memo; // 备注
    private Long categoryId; // 材料分类id
    private String categoryName; // 材料分类名称
    private String categoryInnerCode; // 材料分类内码
    private Long managerId; //审核人Id
    private String managerName; //审核人名称
    private String managerCode; //审核人编码
    private String managerPostName; //审核人岗位
    private Long managerPostId; //审核人岗位Id

    /*导出使用*/
    private String categoryCode; // 材料分类编码
    private String levelOneName; // 一级分类名称
    private String levelOneCode; //一级分类编码
    private String levelTwoName; // 一级分类名称
    private String levelTwoCode; //一级分类编码

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public String getLevelOneName() {
        return levelOneName;
    }

    public void setLevelOneName(String levelOneName) {
        this.levelOneName = levelOneName;
    }

    public String getLevelOneCode() {
        return levelOneCode;
    }

    public void setLevelOneCode(String levelOneCode) {
        this.levelOneCode = levelOneCode;
    }

    public String getLevelTwoName() {
        return levelTwoName;
    }

    public void setLevelTwoName(String levelTwoName) {
        this.levelTwoName = levelTwoName;
    }

    public String getLevelTwoCode() {
        return levelTwoCode;
    }

    public void setLevelTwoCode(String levelTwoCode) {
        this.levelTwoCode = levelTwoCode;
    }

    public Long getManagerPostId() {
        return managerPostId;
    }

    public void setManagerPostId(Long managerPostId) {
        this.managerPostId = managerPostId;
    }

    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }

    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }

    public String getManagerCode() {
        return managerCode;
    }

    public void setManagerCode(String managerCode) {
        this.managerCode = managerCode;
    }

    public String getManagerPostName() {
        return managerPostName;
    }

    public void setManagerPostName(String managerPostName) {
        this.managerPostName = managerPostName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getCategoryInnerCode() {
        return categoryInnerCode;
    }

    public void setCategoryInnerCode(String categoryInnerCode) {
        this.categoryInnerCode = categoryInnerCode;
    }
    
}
